@@ -1,49 +1,55 @@
-#' Consider socio-economic aspects in healthiar assessments
+#' Consider socio-economic aspects in the attributable health impacts
 
 # DESCRIPTION ##################################################################
 #' @description
-#' This function considers socio-economic aspects (e.g. multiple deprivation index) in the attributable health impacts. If nothing is entered in the argument \code{output_attribute}, it is assumed that all data come from a table and the argument refer to the columns of that table.
+#' This function analyzes differences in attributable health impacts across study areas
+#' looking at the value of a socio-economic indicator (e.g. multiple deprivation index).
+#' If nothing is entered in the argument \code{output_attribute},
+#' it is assumed that all data come from a table and the argument refer to the columns of that table.
 
 # ARGUMENTS ####################################################################
 #' @param output_attribute
 #' \code{List} containing the outputs of the \code{healthiar::attribute_health()} assessments for each age group (each list element should be an age group-specific assessment).
-
 #' @param age_group
 #' \code{String vector} with the age groups included in the age standardization. The vector refers to age-dependent data in this function and to \code{output_attribute} (if provided).
-
 #' @param social_indicator
-#' \code{Numeric vector} showing the social indicator used for the analysis, e.g. a deprivation score (indicator of economic wealth) for each geographic unit. Based on this and \code{n_quantile}, \code{social_quantile} will be calculated.
-
+#' \code{Numeric vector} showing the social indicator used for the analysis, e.g. a deprivation score (indicator of economic wealth) for each geographic unit. The length and the values must correspond with \code{geo_id_micro}. If \code{geo_id_micro} is not entered when using argument \code{output_attribute}, \code{social_indicator} must correspond to the column \code{geo_id_micro} in \code{results_by_age_group} of \code{output_attribute}.
 #' @param increasing_deprivation
 #' \code{Boolean} variable (\code{TRUE}/\code{FALSE}) specifying whether an increase in \code{social_indicator} corresponds to an increase (\code{TRUE}) or decrease \code{FALSE} in deprivation. Default: \code{TRUE}.
-
 #' @param n_quantile
 #' \code{Integer value} specifying the number of quantiles in the analysis.
-
 #' @param social_quantile
 #' \code{Integer vector} showing the values from 1 to the number of quantiles assigned to each geographic unit. Either enter \code{social_indicator} and \code{n_quantile} or \code{social_quantile}
-
 #' @param geo_id_micro,
-#' \code{Numeric vector} or \code{string vector} specifying the unique ID codes of each geographic area considered in the assessment (\code{geo_id_micro}) Argument must be entered for iterations. See Details for more info.
-
+#' \code{Numeric vector} or \code{string vector} specifying the unique ID codes of each geographic area considered in the assessment (\code{geo_id_micro}).
 #' @param population
 #' \code{Numeric vector} specifying the population by age group and geographic unit.
-
 #' @param ref_prop_pop
 #' \code{Numeric vector} specifying with the reference proportion of population for each age group. If this argument is empty, the proportion of \code{population} by age group in the provided data will be used.
-
 #' @param impact
 #' \emph{(only if \code{output_attribute} not specified)} \code{Numeric vector} containing the attributable health impacts by both age group and geo id.
-
 #' @param bhd
-#' \emph{(only if \code{output_attribute} not specified)} \code{Numeric vector} specifying the baseline health data of the health outcome of interest per age group. See Details for more info.
-
+#' \emph{(only if \code{output_attribute} not specified)} \code{Numeric vector} specifying the baseline health data of the health outcome of interest per age group.
 #' @param exp
 #'\emph{(only if \code{output_attribute} not specified)} \code{Numeric vector} specifying the exposure level(s) to the environmental stressor.
-
 #' @param pop_fraction
 #' \emph{(only if \code{output_attribute} not specified)} \code{Numeric vector} specifying the population attributable fraction by age group and geographic unit.
 
+# DETAILS ######################################################################
+#' @details
+#'
+#' \strong{Methodology}
+#'
+#' This function estimates the absolute and relative differences in attributable health impacts
+#' comparing study areas with different values for a socio-economic indicator
+#' \insertCite{Renard2019_bmc,Otavova_2022_bmc}{healthiar}.
+#'
+#' Detailed information about the methodology (including equations)
+#' is available in the package vignette.
+#' More specifically, see chapters:
+#' \itemize{
+#'  \item \href{https://swisstph.github.io/healthiar/articles/intro_to_healthiar.html#health-impact-attributable-to-social-indicator}{Health impact attributable to social indicator}}
+#'
 # VALUE ########################################################################
 #' @returns
 #' This function returns a \code{list} containing the impact (absolute and relative) theoretically attributable to the difference in the social indicator (e.g. degree of deprivation) between the quantiles:
@@ -72,35 +78,49 @@
 #' ## Create assessments for multiple geographic units for the age group
 #' ## 40 years and younger
 #' results_age_groups <-
-#'   healthiar::attribute_health(
-#'     age_group = rep(c("below_40", "40_plus"), each = 9037),
-#'     exp_central = c(exdat_socialize$PM25_MEAN, exdat_socialize$PM25_MEAN-0.1),
-#'     cutoff_central = 0,
-#'     rr_central = 1.08,
-#'     erf_shape = "log_linear",
-#'     rr_increment = 10,
-#'     bhd_central =  c(exdat_socialize$MORTALITY_below_40, exdat_socialize$MORTALITY_40_plus),
-#'     population = c(exdat_socialize$POPULATION_below_40, exdat_socialize$POPULATION_40_plus),
-#'     geo_id_micro = rep(exdat_socialize$CS01012020, 2))
+#'    healthiar::attribute_health(
+#'      age_group = exdat_socialize$age_group,
+#'      exp_central = exdat_socialize$pm25_mean,
+#'      cutoff_central = 0,
+#'      rr_central = exdat_socialize$rr,
+#'      erf_shape = "log_linear",
+#'      rr_increment = 10,
+#'      bhd_central = exdat_socialize$mortality,
+#'      population = exdat_socialize$population,
+#'      geo_id_micro = exdat_socialize$geo_unit)
 #'
 #' ## Difference in attributable impacts between geographic units
 #' ## that is attributable to differences in deprivation
 #' results <- socialize(
-#'   age_group = c("below_40", "40_plus"),
-#'   ref_prop_pop = c(0.5, 0.5),
 #'   output_attribute = results_age_groups,
-#'   geo_id_micro = exdat_socialize$CS01012020,
+#'   age_group = exdat_socialize$age_group, # The same as in attribute_health()
+#'   ref_prop_pop = exdat_socialize$ref_prop_pop,
+#'   geo_id_micro = exdat_socialize$geo_unit,
 #'   social_indicator = exdat_socialize$score,
 #'   n_quantile = 10,
 #'   increasing_deprivation = TRUE)
 #'
+#'
 #' results$social_main |>
 #'   dplyr::filter(difference_type == "relative") |>
 #'   dplyr::filter(difference_compared_with == "overall") |>
 #'   dplyr::select(first, last, difference_type, difference_value, comment)
-
+#'
+#'
+#' @seealso
+#' \itemize{
+#'   \item Upstream:
+#'     \code{\link{attribute_health}}, \code{\link{attribute_lifetable}},
+#'      \code{\link{prepare_mdi}},
+#' }
+#'
+#' @references
+#'
+#' \insertAllCited{}
+#'
+#'
 #' @author Alberto Castro & Axel Luyten
-
+#'
 #' @export
 
 socialize <- function(output_attribute = NULL,
@@ -315,10 +335,12 @@ socialize <- function(output_attribute = NULL,
     ## Here use unique() because the user will enter a vector with unique values
     ## and not a vector that fits with a table
     ## (the user entered the output from healthiar)
+
     social_component_before_quantile <-
       tibble::tibble(
-        geo_id_micro = base::unique(input_data$geo_id_micro),
-        social_indicator = social_indicator)
+        geo_id_micro = geo_id_micro,
+        social_indicator = social_indicator) |>
+      dplyr::distinct()
 
     # * * If available ref_prop_pop ################
 
@@ -435,12 +457,11 @@ socialize <- function(output_attribute = NULL,
     }
 
   # Put all data together ####################
-
   input_data_with_quantile <-
     ## Add social_quantile (removing the other columns in social_component)
     dplyr::left_join(
       input_data,
-      social_component[, c("geo_id_micro", "social_quantile")],
+      base::unique(social_component[, c("geo_id_micro", "social_quantile")]),
       by = "geo_id_micro") |>
     ## Add age_order
     dplyr::left_join(
@@ -512,8 +533,8 @@ socialize <- function(output_attribute = NULL,
         bhd_sum = if (has_bhd) base::sum(bhd, na.rm = TRUE) else NULL,
         population_sum = if (has_population) base::sum(population, na.rm = TRUE) else NULL,
         bhd_mean = if (has_bhd) base::mean(bhd, na.rm = TRUE) else NULL,
-        exp_mean = if (has_exp) base::mean(exp, na.rm = TRUE) else NULL,
-        exp_sd = if (has_exp) stats::sd(exp, na.rm = TRUE) else NULL,
+        exp_mean = if (has_exp & is.numeric(exp)) base::mean(exp, na.rm = TRUE) else NULL, # In absolute risk exp is string (pasted)
+        exp_sd = if (has_exp & is.numeric(exp)) stats::sd(exp, na.rm = TRUE) else NULL, # In absolute risk exp is string (pasted)
         pop_fraction_mean = if (has_pop_fraction) base::mean(pop_fraction, na.rm = TRUE) else NULL,
         .groups = "drop") |>
         dplyr::mutate(
@@ -640,9 +661,9 @@ socialize <- function(output_attribute = NULL,
           base::grepl("bhd_", parameter) ~ "baseline health data",
           base::grepl("pop_fraction_", parameter) ~ "population attributable fraction",
           base::grepl("impact_", parameter) ~ "impact"),
-      ## Replace "quantile" with "bottom_quantile"
+      ## Replace "quantile" with "last_quantile"
       difference_compared_with =
-        base::gsub("quantile", "bottom_quantile", difference_compared_with),
+        base::gsub("quantile", "last_quantile", difference_compared_with),
       ## Flag attributable fraction
       is_paf_from_deprivation =
         difference_type == "relative" & difference_compared_with == "overall",
